@@ -2,6 +2,7 @@ package yqlib
 
 import (
 	"container/list"
+	"fmt"
 )
 
 /*
@@ -16,13 +17,13 @@ import (
 */
 
 func collectObjectOperator(d *dataTreeNavigator, originalContext Context, _ *ExpressionNode) (Context, error) {
-	log.Debugf("-- collectObjectOperation")
+	log.Debugf("collectObjectOperation")
 
 	context := originalContext.WritableClone()
 
 	if context.MatchingNodes.Len() == 0 {
 		candidate := &CandidateNode{Kind: MappingNode, Tag: "!!map", Value: "{}"}
-		log.Debugf("-- collectObjectOperation - starting with empty map")
+		log.Debugf("collectObjectOperation - starting with empty map")
 		return context.SingleChildContext(candidate), nil
 	}
 	first := context.MatchingNodes.Front().Value.(*CandidateNode)
@@ -34,6 +35,9 @@ func collectObjectOperator(d *dataTreeNavigator, originalContext Context, _ *Exp
 
 	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
 		candidateNode := el.Value.(*CandidateNode)
+		if len(candidateNode.Content) < len(first.Content) {
+			return Context{}, fmt.Errorf("CollectObject: mismatching node sizes; are you creating a map with mismatching key value pairs?")
+		}
 
 		for i := 0; i < len(first.Content); i++ {
 			log.Debugf("rotate[%v] = %v", i, NodeToString(candidateNode.Content[i]))
@@ -41,7 +45,7 @@ func collectObjectOperator(d *dataTreeNavigator, originalContext Context, _ *Exp
 			rotated[i].PushBack(candidateNode.Content[i])
 		}
 	}
-	log.Debugf("-- collectObjectOperation, length of rotated is %v", len(rotated))
+	log.Debugf("collectObjectOperation, length of rotated is %v", len(rotated))
 
 	newObject := list.New()
 	for i := 0; i < len(first.Content); i++ {
@@ -58,7 +62,7 @@ func collectObjectOperator(d *dataTreeNavigator, originalContext Context, _ *Exp
 			additionCopy.SetParent(nil)
 			additionCopy.Key = nil
 
-			log.Debugf("-- collectObjectOperation, adding result %v", NodeToString(additionCopy))
+			log.Debugf("collectObjectOperation, adding result %v", NodeToString(additionCopy))
 
 			newObject.PushBack(additionCopy)
 		}
@@ -74,7 +78,7 @@ func collect(d *dataTreeNavigator, context Context, remainingMatches *list.List)
 	}
 
 	candidate := remainingMatches.Remove(remainingMatches.Front()).(*CandidateNode)
-	log.Debugf("-- collectObjectOperation - collect %v", NodeToString(candidate))
+	log.Debugf("collectObjectOperation - collect %v", NodeToString(candidate))
 
 	splatted, err := splat(context.SingleChildContext(candidate),
 		traversePreferences{DontFollowAlias: true, IncludeMapKeys: false})
@@ -84,7 +88,7 @@ func collect(d *dataTreeNavigator, context Context, remainingMatches *list.List)
 	}
 
 	if context.MatchingNodes.Len() == 0 {
-		log.Debugf("-- collectObjectOperation - collect context is empty, next")
+		log.Debugf("collectObjectOperation - collect context is empty, next")
 		return collect(d, splatted, remainingMatches)
 	}
 
@@ -94,9 +98,9 @@ func collect(d *dataTreeNavigator, context Context, remainingMatches *list.List)
 		aggCandidate := el.Value.(*CandidateNode)
 		for splatEl := splatted.MatchingNodes.Front(); splatEl != nil; splatEl = splatEl.Next() {
 			splatCandidate := splatEl.Value.(*CandidateNode)
-			log.Debugf("-- collectObjectOperation; splatCandidate: %v", NodeToString(splatCandidate))
+			log.Debugf("collectObjectOperation; splatCandidate: %v", NodeToString(splatCandidate))
 			newCandidate := aggCandidate.Copy()
-			log.Debugf("-- collectObjectOperation; aggCandidate: %v", NodeToString(aggCandidate))
+			log.Debugf("collectObjectOperation; aggCandidate: %v", NodeToString(aggCandidate))
 
 			newCandidate, err = multiply(multiplyPreferences{AppendArrays: false})(d, context, newCandidate, splatCandidate)
 
