@@ -34,7 +34,7 @@ func flatten(node *CandidateNode, depth int) {
 
 func flattenOp(_ *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
 
-	log.Debugf("-- flatten Operator")
+	log.Debugf("flatten Operator")
 	depth := expressionNode.Operation.Preferences.(flattenPreferences).depth
 
 	for el := context.MatchingNodes.Front(); el != nil; el = el.Next() {
