@@ -14,6 +14,16 @@ var omitOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::myMap: {dog: bark, thing: hamster}\n",
 		},
 	},
+	{
+		description: "Omit splat",
+		skipDoc:     true,
+		document:    "{cat: meow, dog: bark, hamster: squeak}\n",
+		expression:  `omit(["dog"])[]`,
+		expected: []string{
+			"D0, P[cat], (!!str)::meow\n",
+			"D0, P[hamster], (!!str)::squeak\n",
+		},
+	},
 	{
 		description: "Omit keys from map",
 		skipDoc:     true,
